crabnet.data.materials\_data.example\_materials\_property package
=================================================================

Module contents
---------------

.. automodule:: crabnet.data.materials_data.example_materials_property
   :members:
   :undoc-members:
   :show-inheritance:
